@@ -235,7 +235,7 @@ def _PyScons(env, target, source, scons, options="-Q", sig_options="", clean = T
         TEMP = os.path.join("temp", base64.b64encode(m.digest(), "+="), '')
     else: TEMP = tempdir
 
-    args += " " + "temp=" + TEMP    
+    options += " temp=" + TEMP + " n=" + str(len(os.path.split(scons))-1)   
     cmd = "scons %s %s -f%s %s" % (options, sig_options, scons, args)
     cleancmd = cmd + " --clean"
     
@@ -285,6 +285,11 @@ def PySconsSetup(args=ARGUMENTS, tools=['default', PYTOOL()]):
                 i = int(a[3:])
                 targets.append((i, args[a]))
             except: pass
+        if a[:1] == "n":
+            try:
+                N = int(args[a])
+            except: pass
+
     sources = [a for i,a in sorted(sources)]
     targets = [a for i,a in sorted(targets)]
 
@@ -294,7 +299,7 @@ def PySconsSetup(args=ARGUMENTS, tools=['default', PYTOOL()]):
     except: basename = None
 
     bn = list(os.path.split(basename))
-    env.SConsignFile(os.path.join([".."] * (len(bn) - 1) + bn + [".sconsign"]))
+    env.SConsignFile(*(os.path.join([".."] * N + bn + [".sconsign"])))
 
     ftargets = [t + ".force" for t in targets]
     if reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
